package xhttp3.internal.tls;

import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLSession;
import javax.security.auth.x500.X500Principal;
import xhttp3.internal.Util;

public final class OkHostnameVerifier implements HostnameVerifier {
   public static final OkHostnameVerifier INSTANCE = new OkHostnameVerifier();
   private static final int ALT_DNS_NAME = 2;
   private static final int ALT_IPA_NAME = 7;

   private OkHostnameVerifier() {
   }

   private boolean verifyIpAddress(String ipAddress, X509Certificate certificate) {
      List var4;
      List var10000 = var4 = getSubjectAltNames(certificate, 7);
      int certificate1 = 0;

      for(int var3 = var10000.size(); certificate1 < var3; ++certificate1) {
         if (ipAddress.equalsIgnoreCase((String)var4.get(certificate1))) {
            return true;
         }
      }

      return false;
   }

   private boolean verifyHostname(String hostname, X509Certificate certificate) {
      hostname = hostname.toLowerCase(Locale.US);
      boolean var3 = false;
      List var4;
      List var10000 = var4 = getSubjectAltNames(certificate, 2);
      int var5 = 0;

      for(int var6 = var10000.size(); var5 < var6; ++var5) {
         var3 = true;
         if (this.verifyHostname(hostname, (String)var4.get(var5))) {
            return true;
         }
      }

      if (!var3) {
         X500Principal certificate1 = certificate.getSubjectX500Principal();
         String certificate2;
         if ((certificate2 = (new DistinguishedNameParser(certificate1)).findMostSpecific("cn")) != null) {
            return this.verifyHostname(hostname, certificate2);
         }
      }

      return false;
   }

   public static List<String> allSubjectAltNames(X509Certificate certificate) {
      X509Certificate var10000 = certificate;
      List certificate1 = getSubjectAltNames(certificate, 7);
      List var1 = getSubjectAltNames(var10000, 2);
      ArrayList var2;
      ArrayList var4 = var2 = new ArrayList;
      var2.<init>(certificate1.size() + var1.size());
      var2.addAll(certificate1);
      var4.addAll(var1);
      return var4;
   }

   private static List<String> getSubjectAltNames(X509Certificate certificate, int type) {
      X509Certificate var10000 = certificate;
      ArrayList certificate1;
      certificate1 = new ArrayList.<init>();

      boolean var10001;
      Collection var18;
      try {
         var18 = var10000.getSubjectAlternativeNames();
      } catch (CertificateParsingException var14) {
         var10001 = false;
         return Collections.emptyList();
      }

      Collection var2 = var18;
      if (var18 == null) {
         try {
            return Collections.emptyList();
         } catch (CertificateParsingException var5) {
            var10001 = false;
         }
      } else {
         Iterator var19;
         try {
            var19 = var2.iterator();
         } catch (CertificateParsingException var13) {
            var10001 = false;
            return Collections.emptyList();
         }

         Iterator var16 = var19;

         while(true) {
            boolean var20;
            try {
               var20 = var16.hasNext();
            } catch (CertificateParsingException var12) {
               var10001 = false;
               break;
            }

            if (!var20) {
               return certificate1;
            }

            List var21;
            try {
               var21 = (List)var16.next();
            } catch (CertificateParsingException var11) {
               var10001 = false;
               break;
            }

            List var3 = var21;
            if (var21 != null) {
               int var22;
               try {
                  var22 = var3.size();
               } catch (CertificateParsingException var10) {
                  var10001 = false;
                  break;
               }

               if (var22 >= 2) {
                  Integer var23;
                  try {
                     var23 = (Integer)var3.get(0);
                  } catch (CertificateParsingException var9) {
                     var10001 = false;
                     break;
                  }

                  Integer var4 = var23;
                  if (var23 != null) {
                     try {
                        var22 = var4;
                     } catch (CertificateParsingException var8) {
                        var10001 = false;
                        break;
                     }

                     if (var22 == type) {
                        String var24;
                        try {
                           var24 = (String)var3.get(1);
                        } catch (CertificateParsingException var7) {
                           var10001 = false;
                           break;
                        }

                        String var17 = var24;
                        if (var24 != null) {
                           try {
                              certificate1.add(var17);
                           } catch (CertificateParsingException var6) {
                              var10001 = false;
                              break;
                           }
                        }
                     }
                  }
               }
            }
         }
      }

      return Collections.emptyList();
   }

   private boolean verifyHostname(String hostname, String pattern) {
      if (hostname != null && hostname.length() != 0 && !hostname.startsWith(".") && !hostname.endsWith("..")) {
         if (pattern != null && pattern.length() != 0 && !pattern.startsWith(".") && !pattern.endsWith("..")) {
            if (!hostname.endsWith(".")) {
               hostname = hostname + '.';
            }

            if (!pattern.endsWith(".")) {
               pattern = pattern + '.';
            }

            String var3;
            if (!(var3 = pattern.toLowerCase(Locale.US)).contains("*")) {
               return hostname.equals(var3);
            } else if (var3.startsWith("*.") && var3.indexOf(42, 1) == -1) {
               if (hostname.length() < var3.length()) {
                  return false;
               } else if ("*.".equals(var3)) {
                  return false;
               } else if (!hostname.endsWith(var3 = var3.substring(1))) {
                  return false;
               } else {
                  int var4;
                  return (var4 = hostname.length() - var3.length()) <= 0 || hostname.lastIndexOf(46, var4 - 1) == -1;
               }
            } else {
               return false;
            }
         } else {
            return false;
         }
      } else {
         return false;
      }
   }

   public boolean verify(String host, SSLSession session) {
      try {
         return this.verify(host, (X509Certificate)session.getPeerCertificates()[0]);
      } catch (SSLException var3) {
         return false;
      }
   }

   public boolean verify(String host, X509Certificate certificate) {
      return Util.verifyAsIpAddress(host) ? this.verifyIpAddress(host, certificate) : this.verifyHostname(host, certificate);
   }
}
